# Tests for student related reports
from zope.interface.verify import verifyClass, verifyObject
from waeup.kofa.students.reports import (
    get_students_by, StudentsReport, IStudentsReport)
from waeup.kofa.students.tests.test_catalog import CatalogTestSetup
from waeup.kofa.testing import FunctionalLayer

class StudentsReportTests(CatalogTestSetup):

    layer = FunctionalLayer

    states = ('created', 'admitted', 'clearance started',
              'clearance requested', 'cleared', 'school fee paid',
              'courses registered', 'courses validated', 'returning', 'Total')

    def test_iface(self):
        # ensure we fullfill interface contracts
        obj = StudentsReport(2010, 'Undergraduate Full-Time')
        verifyClass(IStudentsReport, StudentsReport)
        verifyObject(IStudentsReport, obj)
        return

    def test_title(self):
        obj = StudentsReport(2010, 'Undergraduate Full-Time', author='Bob')
        self.assertTrue(
            obj.title.startswith(
            'StudentsReport_2010_2011_Undergraduate_Full-Time_'))
        return

    def test_get_students_by_session_simple(self):
        # we can get a table with one student
        result1 = get_students_by(2010, 'Undergraduate Full-Time')
        result2 = get_students_by(2009, 'Undergraduate Full-Time')
        self.assertEqual(
            result1,
            ((u'fac1', u'Total',),
             self.states,
             ((1, 0, 0, 0, 0, 0, 0, 0, 0, 1),
              (1, 0, 0, 0, 0, 0, 0, 0, 0, 1),)))
        self.assertEqual(
            result2,
            ((u'fac1', u'Total'),
             self.states,
             ((0, 0, 0, 0, 0, 0, 0, 0, 0, 0),
              (0, 0, 0, 0, 0, 0, 0, 0, 0, 0),)))
        return

    def test_get_students_by_session_multiple(self):
        # we can get a table with several students
        self.create_cert('fac2', 'dept2', 'CERT2')
        result1 = get_students_by(2010, 'Undergraduate Full-Time')
        result2 = get_students_by(2009, 'Undergraduate Full-Time')
        self.assertEqual(
            result1,
            ((u'fac1', u'fac2', u'Total'),
             self.states,
             ((1, 0, 0, 0, 0, 0, 0, 0, 0, 1),
              (0, 0, 0, 0, 0, 0, 0, 0, 0, 0),
              (1, 0, 0, 0, 0, 0, 0, 0, 0, 1),)))
        self.assertEqual(
            result2,
            ((u'fac1', u'fac2', u'Total'),
             self.states,
             ((0, 0, 0, 0, 0, 0, 0, 0, 0, 0),
              (0, 0, 0, 0, 0, 0, 0, 0, 0, 0),
              (0, 0, 0, 0, 0, 0, 0, 0, 0, 0),)))
        return

    def test_create_pdf(self):
        self.create_cert('FAC2', 'dept2', 'CERT2')
        report = StudentsReport(2010, 'Undergraduate Full-Time')
        result = report.create_pdf()
        self.assertTrue(result.startswith('%PDF-'))
        return
